package com.ruoyi.system.controller;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.ruoyi.common.security.utils.SecurityUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.bind.annotation.GetMapping;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import java.util.List;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.system.domain.SysConfig;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISysConfigService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/config" })
public class SysConfigController extends BaseController
{
    @Autowired
    private ISysConfigService configService;
    
    @RequiresPermissions({ "system:config:list" })
    @GetMapping({ "/list" })
    public TableDataInfo list(final SysConfig config) {
        this.startPage();
        final List<SysConfig> list = this.configService.selectConfigList(config);
        return this.getDataTable((List)list);
    }
    
    @Log(title = "参数管理", businessType = BusinessType.EXPORT)
    @RequiresPermissions({ "system:config:export" })
    @PostMapping({ "/export" })
    public void export(final HttpServletResponse response, final SysConfig config) {
        final List<SysConfig> list = this.configService.selectConfigList(config);
        final ExcelUtil<SysConfig> util = (ExcelUtil<SysConfig>)new ExcelUtil((Class)SysConfig.class);
        util.exportExcel(response, (List)list, "参数数据");
    }
    
    @GetMapping({ "/{configId}" })
    public AjaxResult getInfo(@PathVariable final Long configId) {
        return this.success((Object)this.configService.selectConfigById(configId));
    }
    
    @GetMapping({ "/configKey/{configKey}" })
    public AjaxResult getConfigKey(@PathVariable final String configKey) {
        return this.success(this.configService.selectConfigByKey(configKey));
    }
    
    @RequiresPermissions({ "system:config:add" })
    @Log(title = "参数管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody final SysConfig config) {
        if (!this.configService.checkConfigKeyUnique(config)) {
            return this.error("新增参数'" + config.getConfigName() + "'失败，参数键名已存在");
        }
        config.setCreateBy(SecurityUtils.getUsername());
        return this.toAjax(this.configService.insertConfig(config));
    }
    
    @RequiresPermissions({ "system:config:edit" })
    @Log(title = "参数管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody final SysConfig config) {
        if (!this.configService.checkConfigKeyUnique(config)) {
            return this.error("修改参数'" + config.getConfigName() + "'失败，参数键名已存在");
        }
        config.setUpdateBy(SecurityUtils.getUsername());
        return this.toAjax(this.configService.updateConfig(config));
    }
    
    @RequiresPermissions({ "system:config:remove" })
    @Log(title = "参数管理", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{configIds}" })
    public AjaxResult remove(@PathVariable final Long[] configIds) {
        this.configService.deleteConfigByIds(configIds);
        return this.success();
    }
    
    @RequiresPermissions({ "system:config:remove" })
    @Log(title = "参数管理", businessType = BusinessType.CLEAN)
    @DeleteMapping({ "/refreshCache" })
    public AjaxResult refreshCache() {
        this.configService.resetConfigCache();
        return this.success();
    }
}
